import { Dialog, DialogTrigger, DialogClose, DialogDescription, DialogContent, DialogTitle, DialogHeader, DialogFooter } from "@/components/ui/dialog"
import { Button } from "@/components/ui/button"
import { ContextMenuContent, ContextMenuItem, ContextMenuSubTrigger, ContextMenuSeparator, ContextMenuSub, ContextMenuSubContent } from "@/components/ui/context-menu"
import { deleteRecord } from "app/lib/del"
import Link from "next/link"
import { ComponentProps, useState } from "react"
import { Row, Table, TableState } from "@tanstack/react-table"
import { tableNameToItemName } from "app/lib/nameMaps"
import EditSubmissionDialog from "app/submission/edit"

export default function FormContextMenu({ table, row }: ComponentProps<"div"> & { table: Table<any>, row: Row<any> }) {
  const pathname = table.options.meta.pathname
  const selectedRows = table.getSelectedRowModel().flatRows

  const [dialog, setDialog] = useState<"edit" | "delete" | null>("delete")

  return (
    <Dialog modal={true}>
      <ContextMenuContent >
        {pathname !== "/submission" && selectedRows.length <= 1 ?
          <>
            <Link href={`${pathname}/${row.original.id}`}>
              <ContextMenuItem>Inspect</ContextMenuItem>
            </Link>
          </>
          : ""
        }

        {
          pathname === "/submission" ?
            <>
              <DialogTrigger asChild>
                <ContextMenuItem onClick={() => setDialog("edit")}>
                  Edit
                </ContextMenuItem>
              </DialogTrigger>
            </>
            : ""
        }

        {
          selectedRows.length > 0 ?
            <ContextMenuItem onClick={() => { table.resetRowSelection() }}>Deselect</ContextMenuItem>
            : ""
        }
        <ContextMenuSeparator />
        <DialogTrigger asChild>
          <ContextMenuItem className="text-destructive" onClick={() => setDialog("delete")}>Delete</ContextMenuItem>
        </DialogTrigger>
      </ContextMenuContent>
      <DialogContent>
        {
          dialog === "delete" ?
            <>
              <DialogHeader>
                <DialogTitle>Are you sure?</DialogTitle>
                <DialogDescription>
                  Deleting a {tableNameToItemName(table.options.meta.tableName)} cannot be undone!
                </DialogDescription>
              </DialogHeader>
              <DialogFooter>
                <DialogClose asChild>
                  <Button variant="destructive"
                    onClick={() => {
                      deleteRecord(row.original.id, pathname)
                    }}>Yes, delete it!
                  </Button>
                </DialogClose>
              </DialogFooter>
            </>
            : dialog === "edit" ?
              <EditSubmissionDialog
                stories={table.options.meta.stories}
                pubs={table.options.meta.pubs}
                responses={table.options.meta.responses}
                defaults={row.original}
              />
              :
              <>
                <DialogTitle>Edit/delete dialog</DialogTitle>
              </>
        }
      </DialogContent>
    </Dialog>

  )
}
